============
*pypathutil*
============

.. image:: https://img.shields.io/pypi/v/pypathutil

.. image:: https://img.shields.io/github/license/veltzer/pypathutil

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pypathutil

author: Mark Veltzer

version: 0.0.13


